Struct rust_libindy_wrapper::pairwise::Pairwise [−][src]
pub struct Pairwise {}Methods
impl Pairwise[src]
impl Pairwisepub fn does_exist(
wallet_handle: IndyHandle,
their_did: &str
) -> Result<bool, ErrorCode>[src]
pub fn does_exist(
wallet_handle: IndyHandle,
their_did: &str
) -> Result<bool, ErrorCode>pub fn does_exist_timeout(
wallet_handle: IndyHandle,
their_did: &str,
timeout: Duration
) -> Result<bool, ErrorCode>[src]
pub fn does_exist_timeout(
wallet_handle: IndyHandle,
their_did: &str,
timeout: Duration
) -> Result<bool, ErrorCode>timeout- the maximum time this function waits for a response
pub fn does_exist_async<F: 'static>(
wallet_handle: IndyHandle,
their_did: &str,
closure: F
) -> ErrorCode where
F: FnMut(ErrorCode, bool) + Send, [src]
pub fn does_exist_async<F: 'static>(
wallet_handle: IndyHandle,
their_did: &str,
closure: F
) -> ErrorCode where
F: FnMut(ErrorCode, bool) + Send, closure- the closure that is called when finished
Returns
errorcode- errorcode from calling ffi function. The closure receives the return result
pub fn create(
wallet_handle: IndyHandle,
their_did: &str,
my_did: &str,
metadata: Option<&str>
) -> Result<(), ErrorCode>[src]
pub fn create(
wallet_handle: IndyHandle,
their_did: &str,
my_did: &str,
metadata: Option<&str>
) -> Result<(), ErrorCode>pub fn create_timeout(
wallet_handle: IndyHandle,
their_did: &str,
my_did: &str,
metadata: Option<&str>,
timeout: Duration
) -> Result<(), ErrorCode>[src]
pub fn create_timeout(
wallet_handle: IndyHandle,
their_did: &str,
my_did: &str,
metadata: Option<&str>,
timeout: Duration
) -> Result<(), ErrorCode>timeout- the maximum time this function waits for a response
pub fn create_async<F: 'static>(
wallet_handle: IndyHandle,
their_did: &str,
my_did: &str,
metadata: Option<&str>,
closure: F
) -> ErrorCode where
F: FnMut(ErrorCode) + Send, [src]
pub fn create_async<F: 'static>(
wallet_handle: IndyHandle,
their_did: &str,
my_did: &str,
metadata: Option<&str>,
closure: F
) -> ErrorCode where
F: FnMut(ErrorCode) + Send, closure- the closure that is called when finished
Returns
errorcode- errorcode from calling ffi function. The closure receives the return result
pub fn list(wallet_handle: IndyHandle) -> Result<String, ErrorCode>[src]
pub fn list(wallet_handle: IndyHandle) -> Result<String, ErrorCode>pub fn list_timeout(
wallet_handle: IndyHandle,
timeout: Duration
) -> Result<String, ErrorCode>[src]
pub fn list_timeout(
wallet_handle: IndyHandle,
timeout: Duration
) -> Result<String, ErrorCode>timeout- the maximum time this function waits for a response
pub fn list_async<F: 'static>(
wallet_handle: IndyHandle,
closure: F
) -> ErrorCode where
F: FnMut(ErrorCode, String) + Send, [src]
pub fn list_async<F: 'static>(
wallet_handle: IndyHandle,
closure: F
) -> ErrorCode where
F: FnMut(ErrorCode, String) + Send, closure- the closure that is called when finished
Returns
errorcode- errorcode from calling ffi function. The closure receives the return result
pub fn get(
wallet_handle: IndyHandle,
their_did: &str
) -> Result<String, ErrorCode>[src]
pub fn get(
wallet_handle: IndyHandle,
their_did: &str
) -> Result<String, ErrorCode>pub fn get_timeout(
wallet_handle: IndyHandle,
their_did: &str,
timeout: Duration
) -> Result<String, ErrorCode>[src]
pub fn get_timeout(
wallet_handle: IndyHandle,
their_did: &str,
timeout: Duration
) -> Result<String, ErrorCode>timeout- the maximum time this function waits for a response
pub fn get_async<F: 'static>(
wallet_handle: IndyHandle,
their_did: &str,
closure: F
) -> ErrorCode where
F: FnMut(ErrorCode, String) + Send, [src]
pub fn get_async<F: 'static>(
wallet_handle: IndyHandle,
their_did: &str,
closure: F
) -> ErrorCode where
F: FnMut(ErrorCode, String) + Send, closure- the closure that is called when finished
Returns
errorcode- errorcode from calling ffi function. The closure receives the return result
pub fn set_metadata(
wallet_handle: IndyHandle,
their_did: &str,
metadata: Option<&str>
) -> Result<(), ErrorCode>[src]
pub fn set_metadata(
wallet_handle: IndyHandle,
their_did: &str,
metadata: Option<&str>
) -> Result<(), ErrorCode>pub fn set_metadata_timeout(
wallet_handle: IndyHandle,
their_did: &str,
metadata: Option<&str>,
timeout: Duration
) -> Result<(), ErrorCode>[src]
pub fn set_metadata_timeout(
wallet_handle: IndyHandle,
their_did: &str,
metadata: Option<&str>,
timeout: Duration
) -> Result<(), ErrorCode>timeout- the maximum time this function waits for a response
pub fn set_metadata_async<F: 'static>(
wallet_handle: IndyHandle,
their_did: &str,
metadata: Option<&str>,
closure: F
) -> ErrorCode where
F: FnMut(ErrorCode) + Send, [src]
pub fn set_metadata_async<F: 'static>(
wallet_handle: IndyHandle,
their_did: &str,
metadata: Option<&str>,
closure: F
) -> ErrorCode where
F: FnMut(ErrorCode) + Send, closure- the closure that is called when finished
Returns
errorcode- errorcode from calling ffi function. The closure receives the return result